@@ -1320,7 +1320,7 @@ show_other_registry_entries (estream_t outfp)
     { 1, "HKLM\\Software\\Gpg4win:VS-Desktop-Version" },
     { 1, "\\" GNUPG_REGISTRY_DIR ":HomeDir" },
     { 1, "\\" GNUPG_REGISTRY_DIR ":DefaultLogFile" },
-    { 2, "Software\\Microsoft\\Office\\Outlook\\Addins\\GNU.GpgOL"
+    { 2, "\\Software\\Microsoft\\Office\\Outlook\\Addins\\GNU.GpgOL"
       ":LoadBehavior" },
     { 2, "HKCU\\Software\\Microsoft\\Office\\16.0\\Outlook\\Options\\Mail:"
       "ReadAsPlain" },
@@ -1352,6 +1352,7 @@ show_other_registry_entries (estream_t outfp)
   int group = 0;
   char *namebuf = NULL;
   const char *name;
+  int from_hklm;
 
   for (idx=0; (name = names[idx].name); idx++)
     {
@@ -1365,7 +1366,7 @@ show_other_registry_entries (estream_t outfp)
           name = namebuf;
         }
 
-      value = read_w32_reg_string (name);
+      value = read_w32_reg_string (name, &from_hklm);
       if (!value)
         continue;
 
@@ -1380,12 +1381,11 @@ show_other_registry_entries (estream_t outfp)
         }
 
       if (group == 3)
-        es_fprintf (outfp, "### %s=%s\n", names[idx].name, value);
+        es_fprintf (outfp, "### %s=%s%s\n", names[idx].name, value,
+                    from_hklm? " [hklm]":"");
       else
-        es_fprintf (outfp, "### %s\n###   ->%s<-\n", name, value);
-
-      /* FIXME: We may want to add an indiction whethe found via HKLM
-       * or HKCU.  */
+        es_fprintf (outfp, "### %s\n###   ->%s<-%s\n", name, value,
+                    from_hklm? " [hklm]":"");
 
       xfree (value);
     }
@@ -1393,8 +1393,78 @@ show_other_registry_entries (estream_t outfp)
   es_fprintf (outfp, "###\n");
   xfree (namebuf);
 }
+
+
+/* Print registry entries take from a configuration file.  */
+static void
+show_registry_entries_from_file (estream_t outfp)
+{
+  gpg_error_t err;
+  char *fname;
+  estream_t fp;
+  char *line = NULL;
+  size_t length_of_line = 0;
+  size_t  maxlen;
+  ssize_t len;
+  char *value = NULL;
+  int from_hklm;
+  int any = 0;
+
+  fname = make_filename (gnupg_datadir (), "gpgconf.rnames", NULL);
+  fp = es_fopen (fname, "r");
+  if (!fp)
+    {
+      err = gpg_error_from_syserror ();
+      if (gpg_err_code (err) != GPG_ERR_ENOENT)
+        log_error ("error opening '%s': %s\n", fname, gpg_strerror (err));
+      goto leave;
+    }
+
+  maxlen = 2048; /* Set limit.  */
+  while ((len = es_read_line (fp, &line, &length_of_line, &maxlen)) > 0)
+    {
+      if (!maxlen)
+        {
+          err = gpg_error (GPG_ERR_LINE_TOO_LONG);
+          log_error ("error reading '%s': %s\n", fname, gpg_strerror (err));
+          goto leave;
+        }
+      trim_spaces (line);
+      if (*line == '#')
+        continue;
+
+      xfree (value);
+      value = read_w32_reg_string (line, &from_hklm);
+      if (!value)
+        continue;
+
+      if (!any)
+        {
+          any = 1;
+          es_fprintf (outfp, "### Taken from gpgconf.rnames:\n");
+        }
+
+      es_fprintf (outfp, "### %s\n###   ->%s<-%s\n", line, value,
+                  from_hklm? " [hklm]":"");
+
+    }
+  if (len < 0 || es_ferror (fp))
+    {
+      err = gpg_error_from_syserror ();
+      log_error ("error reading '%s': %s\n", fname, gpg_strerror (err));
+    }
+
+ leave:
+  if (any)
+    es_fprintf (outfp, "###\n");
+  xfree (value);
+  xfree (line);
+  es_fclose (fp);
+  xfree (fname);
+}
 #endif /*HAVE_W32_SYSTEM*/
 
+
 /* Show all config files.  */
 static void
 show_configs (estream_t outfp)
@@ -1474,14 +1544,16 @@ show_configs (estream_t outfp)
         if ((sl->flags & 1))
           {
             char *p;
+            int from_hklm;
 
             if (!any)
               {
                 any = 1;
                 es_fprintf (outfp, "###\n### Encountered in config files:\n");
               }
-            if ((p = read_w32_reg_string (sl->d)))
-              es_fprintf (outfp, "### %s ->%s<-\n", sl->d, p);
+            if ((p = read_w32_reg_string (sl->d, &from_hklm)))
+              es_fprintf (outfp, "### %s ->%s<-%s\n", sl->d, p,
+                          from_hklm? " [hklm]":"");
             else
               es_fprintf (outfp, "### %s [not set]\n", sl->d);
             xfree (p);
@@ -1490,6 +1562,7 @@ show_configs (estream_t outfp)
   if (!any)
     es_fprintf (outfp, "###\n");
   show_other_registry_entries (outfp);
+  show_registry_entries_from_file (outfp);
 #endif /*HAVE_W32_SYSTEM*/
 
   free_strlist (list);
